.. _motivations:

Intro
=====

In this section we recap the motivations behind this project.
Choosing the right framework for your research is often challenging and we hope to provide a broader look that could
help deciding whether it meets your needs or not.

The development of the framework is evolving quickly, and the architecture and motivations described in the
:ref:`reference publication <faq_citation>` are becoming outdated.
While that publication remains the reference in case you use the project for your research,
this section provides a constantly updated description aligned with the most recent development news.
